@@ -1,21 +1,25 @@
 #![allow(non_upper_case_globals)]
-// #![deny(missing_docs)]
-// #![deny(missing_debug_implementations)]
-// #![doc = include_str!("../Readme.md")]
+#![allow(mixed_script_confusables)]
+#![deny(missing_docs)]
+#![deny(missing_debug_implementations)]
+#![doc = include_str!("../Readme.md")]
 
-// mod circle;
-// mod point;
+mod circle;
+mod point;
 // mod traits;
 
-pub use float::{Float, Pi};
+pub use float::{π, Float};
 
+/// A 2D point.
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub struct Point {
+    /// The x-coordinate.
     pub x: Float,
+    /// The y-coordinate.
     pub y: Float,
 }
 
-/// A ball in n-dimensional space.
+/// A circle.
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub struct Circle {
     /// Center of the circle.
@@ -24,14 +28,16 @@ pub struct Circle {
     pub radius: Float,
 }
 
+// noinspection NonAsciiCharacters
 #[cfg(feature = "f32")]
 mod float {
     /// Float Type
     pub type Float = f32;
     /// constant π
-    pub const Pi: Float = std::f32::consts::PI;
+    pub const π: Float = std::f32::consts::PI;
 }
 
+// noinspection NonAsciiCharacters
 #[cfg(feature = "f64")]
 mod float {
     /// Float Type
